@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,15 +18,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #include	<config.h>
-#ifdef	DEBUG
-#include	<stdio.h>	/* for debugging */
+#if	HAVE_STDINT_H
+#include	<stdint.h>
+#elif	HAVE_INTTYPES_H
+#include	<inttypes.h>
+#else
+#error No stdint.h or inttypes.h found.
 #endif
 #include	"cdb.h"
 
 /* call after cdb_find (and cdb_datalen) */
 int cdb_get(struct cdb *c, void *buf)
 {
-    uint32	pos	 = cdb_datapos(c);
+    uint32_t	pos	 = cdb_datapos(c);
     
     if (cdb_read(c, buf, cdb_datalen(c), pos) == -1)
       return -1;
