@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,8 +18,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 /* checkset.c */
-void checkset_show(FILE *out, checkset c);
-checkset checkset_new(size_t n);
-void checkset_init(checkset c, size_t n);
-void checkset_free(checkset c);
-
+void checkset_show(FILE *out, checkset *c);
+void checkset_init(checkset *c);
+void checkset_free(checkset *c);
+checkset *checkset_merge(checkset *new, checkset *old, const char *filename);
+checkset *checkset_new();
+ni_checkset *ni_checkset_new();
