@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,8 +20,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef	ELC_WFT_H
 #define	ELC_WFT_H
 
+#define	WFT_VERBOSE		0x01
+#define	WFT_IGNORE_OPENDIR_FAIL	0x02
+
 typedef enum wft_ret_t {
   WFT_ERROR	 = -1,
+  WFT_OPENDIR_FAIL = 1,
   WFT_PROCEED	 = 0,
   WFT_PRUNE,
   WFT_STOP,
@@ -31,5 +35,12 @@ typedef enum wft_ret_t {
 typedef
 wft_ret_t (*wft_cb_t)(const char *fname, const struct stat *sb, void *data);
 
+typedef struct wft_context_struct {
+  char		*rootname;
+  wft_cb_t	callback;
+  void		*cb_data;
+  unsigned int	options;
+} wft_context_t;
+
 #endif
 
