@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,5 +18,5 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 /* elcwft.c */
-int walk_file_tree(const char *root, wft_cb_t callback, void *data);
-
+/* int walk_file_tree(const char *root, wft_cb_t callback, void *data); */
+int walk_file_tree(struct wft_context_struct *ctx);
