@@ -1,6 +1,6 @@
 /*
-hashtbl
-Copyright (C) 2001 Ed Cashin
+hashtbl - a handy and fast, free hash table implementation
+Copyright (C) 2000, 2001 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
